@@ -189,6 +189,47 @@ def chunk_file(fn, chunk_size, use_b64=True, encoding='utf-8'):
         part += 1
         yield dat
 
+def create_schema(d, title, descr, required_keys=None):
+    """
+    Input data object is turned into a schema for use
+    in a kafka_mdml_producer().
+    
+    Parameters
+    ----------
+    d : dict
+        Data object to translate into a schema
+    required_keys : list of str
+        List of strings of the keys that are required in the schema
+    title : str
+        Title of the schema
+    descr : str
+        Description of the schema
+    """
+    schema = {
+        "$schema": f"http://merf.egs.anl.gov/mdml-{title}-auto-schema#",
+        "title": title,
+        "description": descr,
+        "type": "object",
+        "properties": {}
+    }
+    if required_keys is not None:
+        schema['required'] = required_keys
+    keys = d.keys()
+    print(keys)
+    for key in keys:
+        dtype = type(d[key])
+        if dtype == str:
+            schema['properties'][key] = {
+                "type": "string"
+            }
+        elif dtype == float or dtype == int:
+            schema['properties'][key] = {
+                "type": "number"
+            }
+        else:
+            raise Exception(f"Data is currently using an unsupported type: {dtype}")
+    return schema
+
 class kafka_mdml_producer:
     """
     Creates a serializingProducer instance for interacting with the MDML. 
